jgh

Dependents:   Migration

Fork of BLE_API by Bluetooth Low Energy

Revision:
1179:4ab722f8dca0
Parent:
1171:cef71495d95d
Child:
1183:1589830dbdb7
diff -r a4418fcb462f -r 4ab722f8dca0 ble/BLEProtocol.h
--- a/ble/BLEProtocol.h	Wed Apr 06 19:15:28 2016 +0100
+++ b/ble/BLEProtocol.h	Wed Apr 06 19:15:30 2016 +0100
@@ -51,27 +51,16 @@
     typedef uint8_t AddressBytes_t[ADDR_LEN]; /**< 48-bit address, in LSB format. */
 
     /**
      * BLE address. It contains an address-type (AddressType_t) and bytes (AddressBytes_t).
      */
     struct Address_t {
-        AddressType_t  type;    /**< The type of the BLE address. */
-        AddressBytes_t address; /**< The BLE address. */
+        AddressType_t  type;    /**< @ref AddressType_t */
+        AddressBytes_t address; /**< @ref AddressBytes_t */
 
-        /**
-         * Construct an Address_t object with the supplied type and address.
-         *
-         * @param[in] typeIn
-         *              The BLE address type.
-         * @param[in] addressIn
-         *              The BLE address.
-         */
         Address_t(AddressType_t typeIn, const AddressBytes_t& addressIn) : type(typeIn) {
             std::copy(addressIn, addressIn + ADDR_LEN, address);
         }
 
-        /**
-         * Empty constructor.
-         */
         Address_t() : type(), address() {
         }
     };
@@ -51,27 +51,16 @@
 
     /**
-     * BLE address. It contains an address-type (AddressType_t) and bytes (AddressBytes_t).
+     * BLE address. It contains an address-type (@ref AddressType_t) and bytes (@ref AddressBytes_t).
      */
     struct Address_t {